<?php
/* SalesBinder PHP Inventory Display - v1.0
* Caches API calls to a local file which is updated on a 
* given time interval.
*/
class API_cache {
  
  private 
      $_api_key
    , $_update_interval
    , $_cache_file
    , $_api_call;

  public function __construct ($key, $tw, $int=10, $cf='api_cache.json') {
    $this->_api_key = $key;
    $this->_api_call = $tw;
    $this->_update_interval = $int * 60; // minutes to seconds
    $this->_cache_file = realpath(dirname(__FILE__)).'/api_cache/'.$cf;
  }

  /*
   * Updates cache if last modified is greater than
   * update interval and returns cache contents
   */
  public function get_api_cache () {
    if (!file_exists($this->_cache_file) || 
        time() - filemtime($this->_cache_file) > $this->_update_interval) {
      $this->_update_cache();
    }
    return file_get_contents($this->_cache_file);
  }

  /* Http expires date */
  public function get_expires_datetime () {
    if (file_exists($this->_cache_file)) {
      return date (
        'D, d M Y H:i:s \G\M\T', 
        filemtime($this->_cache_file) + ($this->_update_interval)
      );
    }
  }

  /* Makes the api call and updates the cache */
  private function _update_cache () {
    // update from SalesBinder API if past the interval time
    if (!is_writable( realpath(dirname(__FILE__)).'/api_cache/' )) exit('Oops: You need to make the api_cache folder writable.');
    $fp = fopen($this->_cache_file, 'w+'); // open or create cache
    if ($fp) {
      if (flock($fp, LOCK_EX)) {
		
		$ch = curl_init($this->_api_call);
        
        curl_setopt_array($ch, array(
            CURLOPT_USERPWD => $this->_api_key.':x',
            CURLOPT_RETURNTRANSFER => true,
            CURLOPT_SSL_VERIFYHOST => false,
            CURLOPT_SSL_VERIFYPEER => false
        ));
        
        $json = curl_exec($ch);
		curl_close($ch);
		
        fwrite($fp, $json);
        flock($fp, LOCK_UN);
      }
      fclose($fp);
    }
  }
  
}
